pub struct RestartPolicy {
pub max_restarts: u32,
pub restart_window: Duration,
pub restart_delay: Duration,
pub restart_on: RestartTrigger,
}Expand description
Controls automatic feed restart behavior after failures.
Restart semantics
restart_on == Never— never restart, regardless of other fields.max_restarts == 0— never restart, regardless ofrestart_window.max_restarts > 0— allow up to this many restarts withinrestart_window. If the feed stays alive longer than the window the counter resets, allowing further restarts.
Fields
max_restarts: u32Maximum number of restarts before giving up.
0 means never restart — the restart_window cannot override this.
restart_window: DurationReset the restart counter after this much consecutive uptime.
restart_delay: DurationDelay before restarting.
restart_on: RestartTriggerWhat triggers an automatic restart.